/* "Bit Compressor", written by Karolina Soltys */

#include <cstdio>
#include <math.h>

using namespace std;

/* 
in the structure below maximal 111..100..0 sections are kept
value is the number of 1's obtained after decoding all the 1's in this section
zeros is the number of 0's in this section
temp_value is a variable used in function check, representing the value of the section after glueing it with some number of sections preceding it
*/

struct interval {
	int value, zeros;
	int temp_value;
} section [40];

/* 
global variables: 
L, N -            variables given in the problem
sections -        number of maximal 11..100..0 sections
global_value -    number of 1's obtained after decoding all sections left of the
                  section currently processed by the check function
result -          the number of solutions already found
*/

int L, N, sections, global_value, result, casenumber;

inline int min (int a, int b) { if (a < b) return a; else return b;}

/* the first parameter of the check function is the number
of the section currently processed, and the second one is the number of zeros
we can use to decompress the code right of the beginning of this section.
the function is called for the first time in the first section with all of 
the 0's that can be used in the decompression. the function checks all the
possibilities of distribution of 0's among the sections, and in the result 
variable counts those that lead to decompressed code with the given number 
of N 1's
*/


void check (int section_nr, int zeros_res) {

if (section_nr < sections-1) {	
/* we're not in the final section yet */
	if (section[section_nr].zeros <= zeros_res) {
	/* zeros_res exceeds the number of 0's in the section, so it is glued with the following section, what consumes some of the 0's in the zeros_res variable */
		section[section_nr+1].temp_value = section[section_nr].temp_value * (int) pow(2,section[section_nr].zeros + (int) log2(section[section_nr+1].value) + 1) + section[section_nr+1].value;
		check (section_nr+1, zeros_res - section[section_nr].zeros);
	}
	/* in this loop the program checks all possibilities of using some number (or none) of 0's in this section, and transfers right the rest of the 0's */
	for (int i = min (section[section_nr].zeros - 1, zeros_res) ; i >= 2; i--) {
		global_value += section[section_nr].temp_value * (int) pow (2, i);	
		check (section_nr+1, zeros_res - i);
		global_value -= section[section_nr].temp_value * (int) pow (2, i);
	}
	/* below the program deals with a special case of a sequence 10 that cannot be decoded as 11 */
	if (section[section_nr].temp_value != 1 && zeros_res >= 1 && section[section_nr].zeros > 1) {
     	global_value += section[section_nr].temp_value * (int) pow (2, 1);	
		check (section_nr+1, zeros_res - 1);
		global_value -= section[section_nr].temp_value * (int) pow (2, 1);
	}  
        global_value += section[section_nr].temp_value * (int) pow (2, 0);	
		check (section_nr+1, zeros_res);
		global_value -= section[section_nr].temp_value * (int) pow (2, 0);
	/* another special case of a sequence of two 1's that can be decoded both as 11 and 111 */
	if (section[section_nr].temp_value == 3) {
		global_value += 2;	
		check (section_nr+1, zeros_res);
		global_value -= 2;

	}
	/* all cases of distributing zeros_res in the sections following were checked, so the function returns to the preceding section */
	section[section_nr].temp_value = section[section_nr].value;
	return;
} else {
	/* the final section */
	if (zeros_res > section[section_nr].zeros || (section[section_nr].temp_value == 1 && zeros_res == 1)) {section[section_nr].temp_value = section[section_nr].value; return;}
	if ( global_value + section[section_nr].temp_value * pow (2, zeros_res) == N) result++; // a solution is found
	if (zeros_res == 0 && section[section_nr].temp_value == 3 && global_value + 2 == N ) result++; // a special case - the final section is in the form 11[00..0] and none of its 0's are used, so it can be decoded as 11 or as 111
	section[section_nr].temp_value = section[section_nr].value;
	return;
}
}


int main () {

/* 
local variables:
length - length of the compressed code
zeros - number of zeros in the compressed code
code - the compressed code
*/

int length, zeros, i;
char code [41], c;

scanf ("%d%d", &L, &N);
casenumber=0;
while ((L!=0)||(N!=0)) {
	casenumber++;
	for (i=0;i<40;i++) section[i].temp_value = section[i].value = section[i].zeros = 0;
	length = zeros = sections = global_value = result = 0;
	scanf ("%c", &c);
	scanf("%s",code);
	for(length=0; code[length]!='\0'; length++);
	i = 0;
	while (code[i]=='0') {zeros++;i++;}
	while (i < length) {
		while (i < length && code[i]=='1') {section[sections].value = section[sections].value * 2 + 1; i++;}
		while (i < length && code[i]=='0') {section[sections].zeros++; zeros++;i++;}
		sections++;
	}
	for (i=0;i<sections;i++) section[i].temp_value = section[i].value;

/* given L and N we know the number of 0's in the decoded sequence, 
so after counting the 0's in the code we obtain the number of 0's 
added by compression. */

	if((zeros-L+N<0)||(L<N)) result=0; else check(0, zeros - L + N);
	
	switch (result) {
		case 0: printf ("Case #%d: NO\n", casenumber); break;
		case 1: printf ("Case #%d: YES\n", casenumber); break;
		default: printf ("Case #%d: NOT UNIQUE\n", casenumber); break;
	}
	scanf ("%d%d", &L, &N);
	}

return 0;
}

